summaryrefslogtreecommitdiffstats
path: root/libk9copy/mp4dlg.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /libk9copy/mp4dlg.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk9copy/mp4dlg.cpp')
-rw-r--r--libk9copy/mp4dlg.cpp114
1 files changed, 57 insertions, 57 deletions
diff --git a/libk9copy/mp4dlg.cpp b/libk9copy/mp4dlg.cpp
index a5854d7..252c9f0 100644
--- a/libk9copy/mp4dlg.cpp
+++ b/libk9copy/mp4dlg.cpp
@@ -9,120 +9,120 @@
#include "mp4dlg.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
#include <kprogress.h>
-#include <qframe.h>
+#include <tqframe.h>
#include <kpushbutton.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "kprogress.h"
#include "kpushbutton.h"
/*
* Constructs a MP4Dlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-MP4Dlg::MP4Dlg( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+MP4Dlg::MP4Dlg( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "MP4Dlg" );
- setCursor( QCursor( 3 ) );
- MP4DlgLayout = new QGridLayout( this, 1, 1, 11, 6, "MP4DlgLayout");
+ setCursor( TQCursor( 3 ) );
+ MP4DlgLayout = new TQGridLayout( this, 1, 1, 11, 6, "MP4DlgLayout");
- lblTitle = new QLabel( this, "lblTitle" );
- lblTitle->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)4, (QSizePolicy::SizeType)4, 0, 0, lblTitle->sizePolicy().hasHeightForWidth() ) );
- QFont lblTitle_font( lblTitle->font() );
+ lblTitle = new TQLabel( this, "lblTitle" );
+ lblTitle->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)4, (TQSizePolicy::SizeType)4, 0, 0, lblTitle->sizePolicy().hasHeightForWidth() ) );
+ TQFont lblTitle_font( lblTitle->font() );
lblTitle_font.setBold( TRUE );
lblTitle->setFont( lblTitle_font );
- lblTitle->setCursor( QCursor( 3 ) );
+ lblTitle->setCursor( TQCursor( 3 ) );
MP4DlgLayout->addWidget( lblTitle, 0, 0 );
pbProgress = new KProgress( this, "pbProgress" );
- pbProgress->setCursor( QCursor( 3 ) );
+ pbProgress->setCursor( TQCursor( 3 ) );
MP4DlgLayout->addMultiCellWidget( pbProgress, 3, 3, 0, 2 );
- frame3 = new QFrame( this, "frame3" );
- frame3->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, frame3->sizePolicy().hasHeightForWidth() ) );
- frame3->setCursor( QCursor( 3 ) );
- frame3->setFrameShape( QFrame::NoFrame );
- frame3->setFrameShadow( QFrame::Raised );
- frame3Layout = new QGridLayout( frame3, 1, 1, 11, 6, "frame3Layout");
+ frame3 = new TQFrame( this, "frame3" );
+ frame3->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, frame3->sizePolicy().hasHeightForWidth() ) );
+ frame3->setCursor( TQCursor( 3 ) );
+ frame3->setFrameShape( TQFrame::NoFrame );
+ frame3->setFrameShadow( TQFrame::Raised );
+ frame3Layout = new TQGridLayout( frame3, 1, 1, 11, 6, "frame3Layout");
- lblfps = new QLabel( frame3, "lblfps" );
- lblfps->setCursor( QCursor( 3 ) );
- lblfps->setAlignment( int( QLabel::AlignVCenter ) );
+ lblfps = new TQLabel( frame3, "lblfps" );
+ lblfps->setCursor( TQCursor( 3 ) );
+ lblfps->tqsetAlignment( int( TQLabel::AlignVCenter ) );
frame3Layout->addWidget( lblfps, 2, 1 );
- lblRemain = new QLabel( frame3, "lblRemain" );
- lblRemain->setCursor( QCursor( 3 ) );
- lblRemain->setAlignment( int( QLabel::AlignVCenter ) );
+ lblRemain = new TQLabel( frame3, "lblRemain" );
+ lblRemain->setCursor( TQCursor( 3 ) );
+ lblRemain->tqsetAlignment( int( TQLabel::AlignVCenter ) );
frame3Layout->addWidget( lblRemain, 3, 1 );
- lblsize = new QLabel( frame3, "lblsize" );
- lblsize->setCursor( QCursor( 3 ) );
+ lblsize = new TQLabel( frame3, "lblsize" );
+ lblsize->setCursor( TQCursor( 3 ) );
frame3Layout->addWidget( lblsize, 0, 1 );
- lblbitrate = new QLabel( frame3, "lblbitrate" );
- lblbitrate->setCursor( QCursor( 3 ) );
+ lblbitrate = new TQLabel( frame3, "lblbitrate" );
+ lblbitrate->setCursor( TQCursor( 3 ) );
frame3Layout->addWidget( lblbitrate, 1, 1 );
- textLabel2 = new QLabel( frame3, "textLabel2" );
- textLabel2->setCursor( QCursor( 3 ) );
+ textLabel2 = new TQLabel( frame3, "textLabel2" );
+ textLabel2->setCursor( TQCursor( 3 ) );
frame3Layout->addWidget( textLabel2, 2, 0 );
- textLabel2_2 = new QLabel( frame3, "textLabel2_2" );
- textLabel2_2->setCursor( QCursor( 3 ) );
+ textLabel2_2 = new TQLabel( frame3, "textLabel2_2" );
+ textLabel2_2->setCursor( TQCursor( 3 ) );
frame3Layout->addWidget( textLabel2_2, 3, 0 );
- textLabel1 = new QLabel( frame3, "textLabel1" );
- textLabel1->setCursor( QCursor( 3 ) );
+ textLabel1 = new TQLabel( frame3, "textLabel1" );
+ textLabel1->setCursor( TQCursor( 3 ) );
frame3Layout->addWidget( textLabel1, 1, 0 );
- textLabel3 = new QLabel( frame3, "textLabel3" );
- textLabel3->setCursor( QCursor( 3 ) );
+ textLabel3 = new TQLabel( frame3, "textLabel3" );
+ textLabel3->setCursor( TQCursor( 3 ) );
frame3Layout->addWidget( textLabel3, 0, 0 );
MP4DlgLayout->addMultiCellWidget( frame3, 2, 2, 0, 2 );
bCancel = new KPushButton( this, "bCancel" );
- bCancel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bCancel->sizePolicy().hasHeightForWidth() ) );
- bCancel->setCursor( QCursor( 0 ) );
+ bCancel->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bCancel->sizePolicy().hasHeightForWidth() ) );
+ bCancel->setCursor( TQCursor( 0 ) );
bCancel->setProperty( "stdItem", 26 );
MP4DlgLayout->addWidget( bCancel, 5, 2 );
- spacer1 = new QSpacerItem( 225, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer1 = new TQSpacerItem( 225, 21, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
MP4DlgLayout->addMultiCell( spacer1, 5, 5, 0, 1 );
- spacer2 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
+ spacer2 = new TQSpacerItem( 20, 16, TQSizePolicy::Minimum, TQSizePolicy::Fixed );
MP4DlgLayout->addItem( spacer2, 4, 1 );
- image = new QLabel( this, "image" );
- image->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)7, 0, 0, image->sizePolicy().hasHeightForWidth() ) );
- image->setMinimumSize( QSize( 0, 250 ) );
- image->setPaletteBackgroundColor( QColor( 0, 0, 0 ) );
- image->setCursor( QCursor( 3 ) );
+ image = new TQLabel( this, "image" );
+ image->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)7, 0, 0, image->sizePolicy().hasHeightForWidth() ) );
+ image->setMinimumSize( TQSize( 0, 250 ) );
+ image->setPaletteBackgroundColor( TQColor( 0, 0, 0 ) );
+ image->setCursor( TQCursor( 3 ) );
image->setScaledContents( TRUE );
MP4DlgLayout->addMultiCellWidget( image, 1, 1, 0, 2 );
languageChange();
- resize( QSize(416, 475).expandedTo(minimumSizeHint()) );
+ resize( TQSize(416, 475).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( bCancel, SIGNAL( clicked() ), this, SLOT( Cancel() ) );
+ connect( bCancel, TQT_SIGNAL( clicked() ), this, TQT_SLOT( Cancel() ) );
}
/*
@@ -130,7 +130,7 @@ MP4Dlg::MP4Dlg( QWidget* parent, const char* name, WFlags fl )
*/
MP4Dlg::~MP4Dlg()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -141,10 +141,10 @@ void MP4Dlg::languageChange()
{
setCaption( tr2i18n( "k9Copy - transcoding" ) );
lblTitle->setText( tr2i18n( "Encoding" ) );
- lblfps->setText( QString::null );
- lblRemain->setText( QString::null );
- lblsize->setText( QString::null );
- lblbitrate->setText( QString::null );
+ lblfps->setText( TQString() );
+ lblRemain->setText( TQString() );
+ lblsize->setText( TQString() );
+ lblbitrate->setText( TQString() );
textLabel2->setText( tr2i18n( "fps" ) );
textLabel2_2->setText( tr2i18n( "Elapsed Time" ) );
textLabel1->setText( tr2i18n( "Bitrate" ) );
@@ -9,120 +9,120 @@
#include "kpushbutton.h"
/*
- * Constructs a MP4Dlg as a child of 'parent', with the
+ * Constructs a MP4Dlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -130,7 +130,7 @@ MP4Dlg::MP4Dlg( QWidget* parent, const char* name, WFlags fl )
MP4Dlg::~MP4Dlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*